@@ -56,56 +56,56 @@ class ConfigurationTC(TestCase):
 
     def test_default(self):
         cfg = self.cfg
-        self.assertEquals(cfg['dothis'], True)
-        self.assertEquals(cfg['value'], None)
-        self.assertEquals(cfg['multiple'], ('yop','yep'))
-        self.assertEquals(cfg['number'], 2)
-        self.assertEquals(cfg['choice'], 'yo')
-        self.assertEquals(cfg['multiple-choice'], ('yo', 'ye'))
-        self.assertEquals(cfg['named'], {'key': 'val'})
+        self.assertEqual(cfg['dothis'], True)
+        self.assertEqual(cfg['value'], None)
+        self.assertEqual(cfg['multiple'], ('yop','yep'))
+        self.assertEqual(cfg['number'], 2)
+        self.assertEqual(cfg['choice'], 'yo')
+        self.assertEqual(cfg['multiple-choice'], ('yo', 'ye'))
+        self.assertEqual(cfg['named'], {'key': 'val'})
 
     def test_base(self):
         cfg = self.cfg
         cfg.set_option('number', '0')
-        self.assertEquals(cfg['number'], 0)
+        self.assertEqual(cfg['number'], 0)
         self.assertRaises(OptionValueError, cfg.set_option, 'number', 'youpi')
         self.assertRaises(OptionValueError, cfg.set_option, 'choice', 'youpi')
         self.assertRaises(OptionValueError, cfg.set_option, 'multiple-choice', ('yo', 'y', 'ya'))
         cfg.set_option('multiple-choice', 'yo, ya')
-        self.assertEquals(cfg['multiple-choice'], ['yo', 'ya'])
-        self.assertEquals(cfg.get('multiple-choice'), ['yo', 'ya'])
-        self.assertEquals(cfg.get('whatever'), None)
+        self.assertEqual(cfg['multiple-choice'], ['yo', 'ya'])
+        self.assertEqual(cfg.get('multiple-choice'), ['yo', 'ya'])
+        self.assertEqual(cfg.get('whatever'), None)
 
     def test_load_command_line_configuration(self):
         cfg = self.cfg
         args = cfg.load_command_line_configuration(['--choice', 'ye', '--number', '4',
                                                     '--multiple=1,2,3', '--dothis=n',
                                                     'other', 'arguments'])
-        self.assertEquals(args, ['other', 'arguments'])
-        self.assertEquals(cfg['dothis'], False)
-        self.assertEquals(cfg['multiple'], ['1', '2', '3'])
-        self.assertEquals(cfg['number'], 4)
-        self.assertEquals(cfg['choice'], 'ye')
-        self.assertEquals(cfg['value'], None)
+        self.assertEqual(args, ['other', 'arguments'])
+        self.assertEqual(cfg['dothis'], False)
+        self.assertEqual(cfg['multiple'], ['1', '2', '3'])
+        self.assertEqual(cfg['number'], 4)
+        self.assertEqual(cfg['choice'], 'ye')
+        self.assertEqual(cfg['value'], None)
         args = cfg.load_command_line_configuration(['-v', 'duh'])
-        self.assertEquals(args, [])
-        self.assertEquals(cfg['value'], 'duh')
-        self.assertEquals(cfg['dothis'], False)
-        self.assertEquals(cfg['multiple'], ['1', '2', '3'])
-        self.assertEquals(cfg['number'], 4)
-        self.assertEquals(cfg['choice'], 'ye')
+        self.assertEqual(args, [])
+        self.assertEqual(cfg['value'], 'duh')
+        self.assertEqual(cfg['dothis'], False)
+        self.assertEqual(cfg['multiple'], ['1', '2', '3'])
+        self.assertEqual(cfg['number'], 4)
+        self.assertEqual(cfg['choice'], 'ye')
 
     def test_load_configuration(self):
         cfg = self.cfg
         args = cfg.load_configuration(choice='ye', number='4',
                                       multiple='1,2,3', dothis='n',
                                       multiple_choice=('yo', 'ya'))
-        self.assertEquals(cfg['dothis'], False)
-        self.assertEquals(cfg['multiple'], ['1', '2', '3'])
-        self.assertEquals(cfg['number'], 4)
-        self.assertEquals(cfg['choice'], 'ye')
-        self.assertEquals(cfg['value'], None)
-        self.assertEquals(cfg['multiple-choice'], ('yo', 'ya'))
+        self.assertEqual(cfg['dothis'], False)
+        self.assertEqual(cfg['multiple'], ['1', '2', '3'])
+        self.assertEqual(cfg['number'], 4)
+        self.assertEqual(cfg['choice'], 'ye')
+        self.assertEqual(cfg['value'], None)
+        self.assertEqual(cfg['multiple-choice'], ('yo', 'ya'))
 
     def test_load_configuration_file_case_insensitive(self):
         file = tempfile.mktemp()
@@ -136,17 +136,17 @@ diffgroup=zou
 """)
             stream.close()
             self.cfg.load_file_configuration(file)
-            self.assertEquals(self.cfg['dothis'], False)
-            self.assertEquals(self.cfg['value'], None)
-            self.assertEquals(self.cfg['multiple'], ['yop','yepii'])
-            self.assertEquals(self.cfg['diffgroup'], 'zou')
+            self.assertEqual(self.cfg['dothis'], False)
+            self.assertEqual(self.cfg['value'], None)
+            self.assertEqual(self.cfg['multiple'], ['yop','yepii'])
+            self.assertEqual(self.cfg['diffgroup'], 'zou')
         finally:
             os.remove(file)
 
     def test_generate_config(self):
         stream = StringIO()
         self.cfg.generate_config(stream)
-        self.assertLinesEquals(stream.getvalue().strip(), """[TEST]
+        self.assertMultiLineEqual(stream.getvalue().strip(), """[TEST]
 
 dothis=yes
 
@@ -167,14 +167,13 @@ named=key:val
 
 [AGROUP]
 
-diffgroup=pouet
-""")
+diffgroup=pouet""")
 
     def test_generate_config_with_space_string(self):
         self.cfg['value'] = '    '
         stream = StringIO()
         self.cfg.generate_config(stream)
-        self.assertLinesEquals(stream.getvalue().strip(), """[TEST]
+        self.assertMultiLineEqual(stream.getvalue().strip(), """[TEST]
 
 dothis=yes
 
@@ -195,8 +194,7 @@ named=key:val
 
 [AGROUP]
 
-diffgroup=pouet
-""")
+diffgroup=pouet""")
 
 
     def test_loopback(self):
@@ -208,12 +206,12 @@ diffgroup=pouet
             stream.close()
             new_cfg = MyConfiguration(name='testloop', options=options)
             new_cfg.load_file_configuration(f)
-            self.assertEquals(cfg['dothis'], new_cfg['dothis'])
-            self.assertEquals(cfg['multiple'], new_cfg['multiple'])
-            self.assertEquals(cfg['number'], new_cfg['number'])
-            self.assertEquals(cfg['choice'], new_cfg['choice'])
-            self.assertEquals(cfg['value'], new_cfg['value'])
-            self.assertEquals(cfg['multiple-choice'], new_cfg['multiple-choice'])
+            self.assertEqual(cfg['dothis'], new_cfg['dothis'])
+            self.assertEqual(cfg['multiple'], new_cfg['multiple'])
+            self.assertEqual(cfg['number'], new_cfg['number'])
+            self.assertEqual(cfg['choice'], new_cfg['choice'])
+            self.assertEqual(cfg['value'], new_cfg['value'])
+            self.assertEqual(cfg['multiple-choice'], new_cfg['multiple-choice'])
         finally:
             os.remove(f)
 
@@ -221,7 +219,7 @@ diffgroup=pouet
         self.assertRaises(OptionValueError,
                           self.cfg.__setitem__, 'multiple-choice', ('a', 'b'))
         self.cfg['multiple-choice'] = ('yi', 'ya')
-        self.assertEquals(self.cfg['multiple-choice'], ('yi', 'ya'))
+        self.assertEqual(self.cfg['multiple-choice'], ('yi', 'ya'))
 
     def test_help(self):
         self.cfg.add_help_section('bonus', 'a nice additional help')
@@ -235,21 +233,20 @@ diffgroup=pouet
 
 Options:
   -h, --help            show this help message and exit
-  --dothis=<y or n>
+  --dothis=<y or n>     
   -v<string>, --value=<string>
   --multiple=<comma separated values>
                         you can also document the option [current: yop,yep]
   --number=<int>        boom [current: 2]
-  --choice=<yo|ye>
+  --choice=<yo|ye>      
   --multiple-choice=<yo|ye>
-  --named=<key=val>
+  --named=<key=val>     
 
-Agroup:
-  --diffgroup=<key=val>
+  Agroup:
+    --diffgroup=<key=val>
 
-Bonus:
-  a nice additional help
-"""
+  Bonus:
+    a nice additional help"""
         if version_info < (2, 5):
             # 'usage' header is not capitalized in this version
             USAGE = USAGE.replace('Usage: ', 'usage: ')
@@ -270,8 +267,7 @@ options:
   Bonus:
     a nice additional help
 """
-
-        self.assertLinesEquals(help, USAGE, striplines=True)
+        self.assertMultiLineEqual(help, USAGE)
 
 
     def test_manpage(self):
@@ -285,7 +281,7 @@ options:
         read_old_config(self.cfg, changes, 'data/test.ini')
         stream = StringIO()
         self.cfg.generate_config(stream)
-        self.assertLinesEquals(stream.getvalue().strip(), """[TEST]
+        self.assertMultiLineEqual(stream.getvalue().strip(), """[TEST]
 
 dothis=yes
 
@@ -306,8 +302,7 @@ named=key:val
 
 [AGROUP]
 
-diffgroup=pouet
-""")
+diffgroup=pouet""")
 
 class Linter(OptionsManagerMixIn, OptionsProviderMixIn):
     options = (
@@ -328,7 +323,7 @@ class RegrTC(TestCase):
 
     def test_load_defaults(self):
         self.linter.load_command_line_configuration([])
-        self.assertEquals(self.linter.config.profile, False)
+        self.assertEqual(self.linter.config.profile, False)
 
 
 if __name__ == '__main__':
